@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2009-2012 by Gerardo Orellana <goaccess@prosoftcorp.com>
+ * Copyright (C) 2009-2013 by Gerardo Orellana <goaccess@prosoftcorp.com>
  * GoAccess - An Ncurses apache weblog analyzer & interactive viewer
  *
  * This program is free software; you can redistribute it and/or
@@ -19,20 +19,18 @@
  */
 
 #if HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #ifndef OUTPUT_H_INCLUDED
 #define OUTPUT_H_INCLUDED
 
-typedef struct GOutput_ GOutput;
+#define OUTPUT_N        10
 
-struct GOutput_
-{
-   char *data;
-   int hits;
-};
+#include "gdashboard.h"
+#include "parser.h"
+#include "settings.h"
 
-void output_html (struct logger *logger);
+void output_html (GLog * logger, GHolder * holder);
 
 #endif
