@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2009-2012 by Gerardo Orellana <goaccess@prosoftcorp.com>
+ * Copyright (C) 2009-2013 by Gerardo Orellana <goaccess@prosoftcorp.com>
  * GoAccess - An Ncurses apache weblog analyzer & interactive viewer
  *
  * This program is free software; you can redistribute it and/or
@@ -21,19 +21,51 @@
 #ifndef UTIL_H_INCLUDED
 #define UTIL_H_INCLUDED
 
+#define ARRAY_SIZE(a) (sizeof(a) / sizeof(a[0]))
+
+#define REGEX_ERROR 100
+#define DATE_LEN     12         /* date length */
+#define KB          1024
+#define MB          (KB * 1024)
+#define GB          (MB * 1024)
+
+#define MILS        1000ULL
+#define SECS        1000000ULL
+#define MINS        60000000ULL
+#define HOUR        3600000000ULL
+
+typedef enum
+{
+   BROWSER,
+   BROWSER_TYPE
+} GBrowserStr;
+
+typedef enum
+{
+   OPESYS,
+   OPESYS_TYPE
+} GOpeSysStr;
+
 char *alloc_string (const char *str);
-int count_occurrences (const char *s1, char c);
-char *convert_date (char *result, char *data, int size);
-int invalid_ipaddr (char *str);
-char *reverse_ip (char *str);
-off_t file_size (const char *filename);
-char *verify_os (char *str);
+char *char_repeat (int n, char c);
 char *char_replace (char *str, char o, char n);
-char *verify_browser (char *str);
-char *verify_status_code (char *str);
-char *trim_str (char *str);
-char *filesize_str (off_t log_size);
 char *clean_date (char *s);
 char *clean_month (char *s);
+char *convert_date (char *result, char *data, char *from, char *to, int size);
+char *filesize_str (unsigned long long log_size);
+char *int_to_str (int d);
+char *reverse_ip (char *str);
+char *secs_to_str (int secs);
+char *substring (const char *str, int begin, int len);
+char *trim_str (char *str);
+char *usecs_to_str (unsigned long long usec);
+char *verify_browser (const char *str, GBrowserStr b_type);
+char *verify_os (const char *str, GOpeSysStr o_type);
+char *verify_status_code (char *str);
+char *verify_status_code_type (const char *str);
+int count_occurrences (const char *s1, char c);
+int intlen (int num);
+int invalid_ipaddr (char *str);
+off_t file_size (const char *filename);
 
 #endif
